==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescription } from "./WebRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebRowSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectorTemplateDetailsDescriptionMetadata.c(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.j(WebRowSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Index", "Number:double");
            a.item("RowID", "Unknown");
            a.item("Key", "Unknown");
            a.item("Selected", "Boolean");
        }
        static d(a) {
            WebRowSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.aa("WebRowSelectorTemplateDetails", () => new WebRowSelectorTemplateDetailsDescription());
            a.z("WebRowSelectorTemplateDetails", WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebRowSelectorTemplateDetailsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectorTemplateDetailsDescriptionMetadata, 'WebRowSelectorTemplateDetailsDescriptionMetadata');
    WebRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebRowSelectorTemplateDetailsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescription } from "./WebRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebRowSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectorTemplateDetailsDescriptionMetadata.c(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Index", "Number:double");
            a.item("RowID", "Unknown");
            a.item("Key", "Unknown");
            a.item("Selected", "Boolean");
        }
        static d(a) {
            WebRowSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ac("WebRowSelectorTemplateDetails", () => new WebRowSelectorTemplateDetailsDescription());
            a.ab("WebRowSelectorTemplateDetails", WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebRowSelectorTemplateDetailsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectorTemplateDetailsDescriptionMetadata, 'WebRowSelectorTemplateDetailsDescriptionMetadata');
    WebRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebRowSelectorTemplateDetailsDescriptionMetadata;
})();
